@@ -25,6 +25,7 @@
 
 #include <QObject>
 #include <QHash>
+#include <QDBusContext>
 
 #include "types.h"
 #include "rfkill.h"
@@ -44,7 +45,7 @@ class Adapter;
 class Device;
 class AdapterPrivate;
 
-class ManagerPrivate : public QObject
+class ManagerPrivate : public QObject, protected QDBusContext
 {
     Q_OBJECT
 
@@ -63,7 +64,7 @@ public:
     void serviceUnregistered();
     void interfacesAdded(const QDBusObjectPath &objectPath, const QVariantMapMap &interfaces);
     void interfacesRemoved(const QDBusObjectPath &objectPath, const QStringList &interfaces);
-    void adapterRemoved(AdapterPtr adapter);
+    void adapterRemoved(const AdapterPtr &adapter);
     void adapterPoweredChanged(bool powered);
     void rfkillStateChanged(Rfkill::State state);
 
@@ -71,8 +72,9 @@ public:
     void addDevice(const QString &devicePath, const QVariantMap &properties);
     void removeAdapter(const QString &adapterPath);
     void removeDevice(const QString &devicePath);
-    void setUsableAdapter(AdapterPtr adapter);
+
     bool rfkillBlocked() const;
+    void setUsableAdapter(const AdapterPtr &adapter);
 
     Manager *q;
     Rfkill *m_rfkill;
@@ -95,7 +97,9 @@ Q_SIGNALS:
     void initFinished();
 
 private Q_SLOTS:
+    void propertiesChanged(const QString &interface, const QVariantMap &changed, const QStringList &invalidated);
     void dummy();
+
 };
 
 } // namespace BluezQt
